@@ -88,8 +88,8 @@ Andreas Voegele E<lt>voegelas@cpan.orgE<gt>
 
 =head1 BUGS AND LIMITATIONS
 
-Please report any bugs to C<bug-cpanplus-dist-slackware at rt.cpan.org>, or
-through the web interface at L<https://rt.cpan.org/>.
+Please report any bugs using the issue tracker at
+L<https://github.com/graygnuorg/CPANPLUS-Dist-Slackware/issues>.
 
 =head1 LICENSE AND COPYRIGHT
 
